@@ -71,9 +71,23 @@ class AbstractBuilder(ABC):
 	:param build_dir: The (temporary) build directory.
 	:default build_dir: :file:`{<project_dir>}/build/`
 	:param out_dir: The output directory.
-	:default out_dir: :file:`{<project_dir>}/dist`
+	:default out_dir: :file:`{<project_dir>}/dist/`
 	:param verbose: Whether to enable verbose output.
 	:param colour: Whether to use coloured output.
+
+	.. autosummary-widths:: 1/2
+		:html: 3/10
+
+	.. autoclasssumm:: AbstractBuilder
+		:autosummary-sections: Attributes
+
+	.. latex:clearpage::
+
+	.. autosummary-widths:: 7/16
+		:html: 4/10
+
+	.. autoclasssumm:: AbstractBuilder
+		:autosummary-sections: Methods
 	"""
 
 	def __init__(
@@ -91,7 +105,7 @@ class AbstractBuilder(ABC):
 		#: The pyproject.toml directory
 		self.project_dir: PathPlus = traverse_to_file(PathPlus(project_dir), "pyproject.toml")
 
-		#: Configuration parsed from "pyproject.toml".
+		#: Configuration parsed from ``pyproject.toml``.
 		self.config: Dict[str, Any] = dict(config)
 
 		#: The archive name, without the tag
@@ -174,6 +188,10 @@ class AbstractBuilder(ABC):
 			target.write_clean(py_file.read_text())
 			self.report_copied(py_file, target)
 
+	def _echo_if_v(self, *args, **kwargs):
+		if self.verbose:
+			self._echo(*args, **kwargs)
+
 	def report_copied(self, source: pathlib.Path, target: pathlib.Path) -> None:
 		"""
 		Report that a file has been copied into the build directory.
@@ -182,26 +200,30 @@ class AbstractBuilder(ABC):
 
 			Copying {source} -> {target.relative_to(self.build_dir)}
 
+		.. latex:vspace:: -5px
+
 		:param source: The source file
 		:param target: The file in the build directory.
 		"""
 
-		if self.verbose:
-			self._echo(f"Copying {source.resolve().as_posix()} -> {target.relative_to(self.build_dir).as_posix()}")
+		self._echo_if_v(
+				f"Copying {source.resolve().as_posix()} -> {target.relative_to(self.build_dir).as_posix()}"
+				)
 
 	def report_removed(self, removed_file: pathlib.Path) -> None:
 		"""
-		Report that a file has been removed from the build directory.
+		Reports the removal of a file from the build directory.
 
 		The format is::
 
 			Removing {removed_file.relative_to(self.build_dir)}
 
+		.. latex:vspace:: -5px
+
 		:param removed_file:
 		"""
 
-		if self.verbose:
-			self._echo(f"Removing {removed_file.relative_to(self.build_dir).as_posix()}")
+		self._echo_if_v(f"Removing {removed_file.relative_to(self.build_dir).as_posix()}")
 
 	def report_written(self, written_file: pathlib.Path) -> None:
 		"""
@@ -211,11 +233,12 @@ class AbstractBuilder(ABC):
 
 			Writing {written_file.relative_to(self.build_dir)}
 
+		.. latex:vspace:: -5px
+
 		:param written_file:
 		"""
 
-		if self.verbose:
-			self._echo(f"Writing {written_file.relative_to(self.build_dir).as_posix()}")
+		self._echo_if_v(f"Writing {written_file.relative_to(self.build_dir).as_posix()}")
 
 	def copy_additional_files(self) -> None:
 		"""
@@ -257,6 +280,9 @@ class AbstractBuilder(ABC):
 
 			elif parts[0] == "recursive-include":
 				for include_file in sort_paths(*(self.project_dir / parts[1]).rglob(parts[2])):
+					if "__pycache__" in include_file.parts:
+						continue
+
 					if include_file.is_file():
 						copy_file(filename=include_file)
 
@@ -299,15 +325,16 @@ class AbstractBuilder(ABC):
 
 		return
 
-	def write_license(self, dest_dir: PathPlus):
+	def write_license(self, dest_dir: PathPlus, dest_filename: str = "LICENSE"):
 		"""
 		Write the ``LICENSE`` file.
 
-		:param dest_dir: The directory to write the files into.
+		:param dest_dir: The directory to write the file into.
+		:param dest_filename: The name of the file to write in ``dest_dir``.
 		"""
 
 		if self.config.get("license", None) is not None:
-			target = dest_dir / "LICENSE"
+			target = dest_dir / dest_filename
 			target.parent.maybe_make(parents=True)
 			target.write_clean(self.config["license"].text)
 			self.report_written(target)
@@ -348,7 +375,8 @@ class AbstractBuilder(ABC):
 
 		for entry in self.config["maintainers"]:
 			if entry["name"] and entry["email"]:
-				maintainer_email.append("{name} <{email}>".format_map(entry))
+				address = Address(entry["name"], addr_spec=entry["email"])
+				author_email.append(str(address))
 			elif entry["email"]:
 				maintainer_email.append(entry["email"])
 			elif entry["name"]:
@@ -372,9 +400,12 @@ class AbstractBuilder(ABC):
 		if self.config["keywords"]:
 			metadata["Keywords"] = ','.join(self.config["keywords"])
 
+		seen_hp = False
+
 		for category, url in self.config["urls"].items():
-			if category.lower() in {"homepage", "home page"}:
+			if category.lower() in {"homepage", "home page"} and not seen_hp:
 				metadata["Home-page"] = url
+				seen_hp = True
 			else:
 				metadata["Project-URL"] = f"{category}, {url}"
 
@@ -474,7 +505,10 @@ class SDistBuilder(AbstractBuilder):
 		with tarfile.open(sdist_filename, mode="w:gz", format=tarfile.PAX_FORMAT) as sdist_archive:
 			for file in self.build_dir.rglob('*'):
 				if file.is_file():
-					sdist_archive.add(str(file), arcname=file.relative_to(self.build_dir).as_posix())
+					sdist_archive.add(
+							str(file),
+							arcname=posixpath.join(self.archive_name, file.relative_to(self.build_dir).as_posix()),
+							)
 
 		self._echo(Fore.GREEN(f"Source distribution created at {sdist_filename.resolve().as_posix()}"))
 		return os.path.basename(sdist_filename)
@@ -582,6 +616,11 @@ class WheelBuilder(AbstractBuilder):
 	:param out_dir: The output directory.
 	:default out_dir: :file:`{<project_dir>}/dist`
 	:param verbose: Enable verbose output.
+
+	.. autosummary-widths:: 11/32
+		:html: 4/10
+
+	.. latex:vspace:: -10px
 	"""
 
 	@property
@@ -664,6 +703,17 @@ class WheelBuilder(AbstractBuilder):
 		wheel_file.write_clean(str(wheel))
 		self.report_written(wheel_file)
 
+	def write_top_level(self, dist_info: PathPlus) -> None:
+		"""
+		Write the ``top_level.txt`` file to the ``*.dist-info`` directory.
+
+		:param dist_info: The absolute path to the ``*.dist-info`` directory.
+		"""
+
+		top_level = first(posixpath.split(self.config["package"]), default=self.config["package"])
+		(dist_info / "top_level.txt").write_clean(top_level)
+		self.report_written(dist_info / "top_level.txt")
+
 	def create_wheel_archive(self) -> str:
 		"""
 		Create the wheel archive.
@@ -717,12 +767,9 @@ class WheelBuilder(AbstractBuilder):
 		self.write_entry_points()
 		self.write_metadata(self.dist_info / "METADATA")
 		self.write_wheel()
+		self.write_top_level(self.dist_info)
 		self.call_additional_hooks()
 
-		top_level = first(posixpath.split(self.config["package"]), default=self.config["package"])
-		(self.dist_info / "top_level.txt").write_clean(top_level)
-		self.report_written(self.dist_info / "top_level.txt")
-
 		return self.create_wheel_archive()
 
 	build = build_wheel
